@@ -1,4 +1,4 @@
 from blocksync.file import File
 from blocksync.syncer import Syncer
 
-__all__ = [File, Syncer]
+__all__ = ["File", "Syncer"]
