@@ -9,13 +9,8 @@ __all__ = ["validate_callback", "generate_random_data"]
 def validate_callback(c: Callable, n: int = 0) -> bool:
     if callable(c):
         sig = signature(c)
-
         if len(sig.parameters) < n:
-            raise ValueError(
-                "{} least required {} arguments, but {}".format(
-                    c, n, len(sig.parameters)
-                )
-            )
+            raise ValueError(f"{c} least required {n} arguments, but {len(sig.parameters)}")
         return True
     raise TypeError("{} is not callable".format(c))
 
